// Dotenv
require('dotenv').config();

// Webpack config
const webpack = require('webpack');
const path = require('path');
const ManifestPlugin = require('webpack-manifest-plugin');
const ChunkManifestPlugin = require('chunk-manifest-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

const nodeEnv = process.env.NODE_ENV || 'development';
const isProd = nodeEnv === 'production';

const resourcePath = path.join(__dirname, './resources/assets');
const buildPath = path.join(__dirname, './public');

const libraryName = 'react-bs-datatable';

// Common plugins
const plugins = [
  new webpack.DefinePlugin({
    'process.env': { NODE_ENV: JSON.stringify(nodeEnv) }
  })
];

const loaders = [
  {
    test: /\.(jsx|js)$/,
    loader: 'babel-loader',
    exclude: /node_modules/
  },
  {
    test: /\.(woff2?|ttf|eot|svg)(\?v=\d+\.\d+\.\d+)?$/,
    loader: isProd ? "file-loader?publicPath=../&name=fonts/[name].[ext]" :
                     "file-loader?name=/fonts/[name].[ext]"
  },
];

// Environment settings
if (isProd) {
  plugins.push(
    new webpack.LoaderOptionsPlugin({
      minimize: true,
      debug: false
    }),
    new webpack.optimize.UglifyJsPlugin({
      compress: {
        warnings: false,
        screw_ie8: true,
        conditionals: true,
        unused: true,
        comparisons: true,
        sequences: true,
        dead_code: true,
        evaluate: true,
        if_return: true,
        join_vars: true,
      },
      output: {
        comments: false
      },
    }),
    new ExtractTextPlugin({
      filename: 'css/[name].min.css',
      allChunks: true,
    })
  );

  loaders.push(
    {
      test: /\.scss$/,
      loader: ExtractTextPlugin.extract({
        fallbackLoader: "style-loader",
        loader: "css-loader!sass-loader",
      }),
    }
  );
}

// Configuration
module.exports = {
  devtool: isProd ? 'cheap-source-map' : 'eval',
  context: resourcePath,
  entry: {
    index: './js/store/index.js'
  },
  output: {
    path: buildPath + '/assets/',
    filename: isProd ? 'js/' + libraryName + '.min.js' : 'js/' + libraryName + '.js',
    library: libraryName,
    libraryTarget: 'umd',
    publicPath: '/assets/'
  },
  module: {
    loaders: loaders
  },
  resolve: {
    extensions: ['.webpack-loader.js', '.web-loader.js', '.loader.js', '.js', '.jsx'],
    modules: [
      resourcePath,
      path.resolve(__dirname, 'node_modules')
    ]
  },
  plugins
};
